@@ -19,13 +19,13 @@
 
 void usage(char *progname)
 {
-	fprintf(stderr, _("usage:  %s [-bq]\n"), progname);
+	fprintf(stderr, _("usage:  %s [-q]\n"), progname);
 	exit(1);
 }
 
 int main(int argc, char **argv)
 {
-	int ret, opt, quiet = 0, preservebools = 1, nargs;
+	int ret, opt, quiet = 0, nargs;
 
 #ifdef USE_NLS
 	setlocale(LC_ALL, "");
@@ -36,7 +36,8 @@ int main(int argc, char **argv)
 	while ((opt = getopt(argc, argv, "bq")) > 0) {
 		switch (opt) {
 		case 'b':
-			preservebools = 0;
+			fprintf(stderr, "%s:  Warning! The -b option is no longer supported, booleans are always preserved across reloads.  Continuing...\n",
+				argv[0]);
 			break;
 		case 'q':
 			quiet = 1;
@@ -50,18 +51,18 @@ int main(int argc, char **argv)
 	nargs = argc - optind;
 	if (nargs > 2)
 		usage(argv[0]);
-	if (nargs >= 1) {
-		fprintf(stderr,
-			"%s:  Warning!  Policy file argument (%s) is no longer supported, installed policy is always loaded.  Continuing...\n",
-			argv[0], argv[optind++]);
+	if (nargs >= 1 && !quiet) {
+			fprintf(stderr,
+				"%s:  Warning!  Policy file argument (%s) is no longer supported, installed policy is always loaded.  Continuing...\n",
+				argv[0], argv[optind++]);
 	}
-	if (nargs == 2) {
+	if (nargs == 2 && ! quiet) {
 		fprintf(stderr,
 			"%s:  Warning!  Boolean file argument (%s) is no longer supported, installed booleans file is always used.  Continuing...\n",
 			argv[0], argv[optind++]);
 	}
 
-	ret = selinux_mkload_policy(preservebools);
+	ret = selinux_mkload_policy(1);
 	if (ret < 0) {
 		fprintf(stderr, _("%s:  Can't load policy:  %s\n"),
 			argv[0], strerror(errno));
