@@ -336,8 +336,8 @@ void process(char *buf)
 				if (!file_exist && errno == ENOENT)
 					return;
 				fprintf(stderr,
-					"%s:  error while labeling files under %s\n",
-					progname, buf);
+					"%s: error while traversing %s: %s\n",
+					progname, buf, strerror(errno));
 				errors++;
 			}
 		}
